def get_coordinate(the_address):
    import time
    import requests
    import random
    the_url = 'https://nominatim.openstreetmap.org/search?q='
    the_format = '&format=json'
    durations = [0, 0.1, 0.3, 0.5, 1, 1.2]

    if (the_address!="" and the_address!=None):
        time.sleep(random.choice(durations))
        return requests.get(the_url+the_address+the_format).text
    else:
        return None




def write_into(origina_address, table_abs_path):
    import pandas as pd
    from . import get_distance

    df = pd.read_csv(table_abs_path)

    df['distance_to_'+origina_address] = df.address

    df['distance_to_'+origina_address]  = df['distance_to_'+origina_address].map(lambda a: get_distance(origina_address, a))

    print(df)

    df.to_csv(table_abs_path)


def main_cmd():
    import argparse
    parser = argparse.ArgumentParser()
    parser.add_argument("address", help="original address, like '125 Queen St, Auckland, 0620' ")
    parser.add_argument("csv_path", help="like '/user/test.csb' ")
    args = parser.parse_args()

    # print("{0:.3f} km".format(get_distance(args.address1, args.address2)))
    write_into(args.address, args.csv_path)




from .osm_coordinate import get_coordinate

def extract_coordinate(the_address):
    import json
    addr= json.loads(get_coordinate(the_address))[0]
    return (addr["lat"], addr["lon"])



def get_distance(addr1, addr2):

    # https://stackoverflow.com/questions/19412462/getting-distance-between-two-points-based-on-latitude-longitude
    # credits to Micheal
    from math import sin, cos, sqrt, atan2, radians

    coord1= extract_coordinate(addr1)
    print(addr1 +"'s location: " + str(coord1))
    coord2 = extract_coordinate(addr2)
    print(addr2 +"'s location: " + str(coord2))

    # approximate radius of earth in km
    R = 6373.0
    lat1 = radians(float(coord1[0]))
    lon1 = radians(float(coord1[1]))
    lat2 = radians(float(coord2[0]))
    lon2 = radians(float(coord2[1]))

    dlon = lon2 - lon1
    dlat = lat2 - lat1

    a = sin(dlat / 2) ** 2 + cos(lat1) * cos(lat2) * sin(dlon / 2) ** 2
    c = 2 * atan2(sqrt(a), sqrt(1 - a))

    distance = R * c

    # print("Result:", distance)
    # print("Should be:", 278.546, "km")
    return distance

def main_cmd():
    import argparse
    parser = argparse.ArgumentParser()
    parser.add_argument("address1", help="address 1, like '125 Queen St, Auckland, 0620' ")
    parser.add_argument("address2", help="address 2, like '127 Queen St, Auckland, 0620' ")
    args = parser.parse_args()

    print("{0:.3f} km".format(get_distance(args.address1, args.address2)))





from unittest import TestCase
from calculator.distance_calc import get_distance

class TestDistanceCalc(TestCase):
    def test_is_zero(self):
        r = get_distance("125 Queen St, Auckland, 0620", "125 Queen St, Auckland, 0620")
        self.assertTrue(r==0)


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="distances_calculator",
    keywords='distance distances_calculator, open street map, csv, big data',
    version="0.1.1",
    author="tim-hub",

    description="Calculate distances between 2 addresses, Distances Calculator is based on open street map api.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/tim-hub/distances_calculator",
    packages=setuptools.find_packages(),
    install_requires=[
        'requests',
        'pandas',
        'argparse',
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    entry_points = {
        'console_scripts': [
            'distance-calc=distances_calculator.command_line:main',
            'distances_writer=distances_calculator.command_line:csv_writer'
        ],
    },
    test_suite='nose.collector',
    tests_require=['nose'],
)